summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorDavid Cole <david.cole@kitware.com>2012-06-12 19:59:41 (GMT)
committerCMake Topic Stage <kwrobot@kitware.com>2012-06-12 19:59:41 (GMT)
commitf848dbfe3ce57790bf4974cc2d142196228427f5 (patch)
tree5954b7d3d5b8bebff7c34203750b4e6b3a7541fc
parentdaf552e3edaf65e4fae3817d74dae8fa584e4bae (diff)
parent8945489c0727e5d9321a817fdb19c750dfcb1045 (diff)
downloadCMake-f848dbfe3ce57790bf4974cc2d142196228427f5.zip
CMake-f848dbfe3ce57790bf4974cc2d142196228427f5.tar.gz
CMake-f848dbfe3ce57790bf4974cc2d142196228427f5.tar.bz2
Merge topic 'VS-Fortran-Intel-2013'
8945489 VS: Set Intel Fortran 13 project version
-rw-r--r--Source/cmLocalVisualStudio7Generator.cxx6
1 files changed, 4 insertions, 2 deletions
diff --git a/Source/cmLocalVisualStudio7Generator.cxx b/Source/cmLocalVisualStudio7Generator.cxx
index 9faf46d..f2ab79d 100644
--- a/Source/cmLocalVisualStudio7Generator.cxx
+++ b/Source/cmLocalVisualStudio7Generator.cxx
@@ -1933,9 +1933,11 @@ cmLocalVisualStudio7Generator
vskey += "\\Packages\\" CM_INTEL_PLUGIN_GUID ";ProductVersion";
cmSystemTools::ReadRegistryValue(vskey.c_str(), intelVersion,
cmSystemTools::KeyWOW64_32);
- if (intelVersion.find("12") == 0 || (intelVersion.find("11") == 0))
+ if (intelVersion.find("13") == 0 ||
+ intelVersion.find("12") == 0 ||
+ intelVersion.find("11") == 0)
{
// Version 11.x and 12.x actually use 11.0 in project files!
intelVersion = "11.0" ;
}
else if(intelVersion.find("10") == 0)
@@ -1933,9 +1933,11 @@ cmLocalVisualStudio7Generator
{
- // Version 11.x and 12.x actually use 11.0 in project files!
+ // Version 11.x, 12.x, and 13.x actually use 11.0 in project files!
intelVersion = "11.0" ;
}